# Generated by Django 2.0.2 on 2019-02-22 16:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0005_auto_20190222_1602'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='job_id',
            field=models.IntegerField(blank=True, default=None, null=True),
        ),
    ]



# Generated by Django 2.0.2 on 2019-02-22 15:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='job_id',
            field=models.IntegerField(default=0),
        ),
    ]



# Generated by Django 2.0.2 on 2019-02-22 16:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0002_job_job_id'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='container',
            field=models.CharField(blank=True, max_length=256),
        ),
        migrations.AlterField(
            model_name='job',
            name='log',
            field=models.TextField(blank=True),
        ),
        migrations.AlterField(
            model_name='job',
            name='tag',
            field=models.CharField(blank=True, max_length=256),
        ),
    ]



from django.db import models


class Job(models.Model):
	job_id = models.IntegerField(blank=True, null=True, default=None)
	driver = models.CharField(max_length=256)
	site = models.CharField(max_length=256)
	status = models.CharField(max_length=256, blank=True)
	tag = models.CharField(max_length=256, blank=True)
	container = models.CharField(max_length=256, blank=True)
	log = models.TextField(blank=True)
	created_at = models.DateTimeField(auto_now_add=True, null=True, blank=True)
	updated_at = models.DateTimeField(auto_now=True)



# Generated by Django 2.0.2 on 2019-02-22 16:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0006_auto_20190222_1606'),
    ]

    operations = [
        migrations.AddField(
            model_name='job',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='job',
            name='updated_at',
            field=models.DateTimeField(auto_now=True),
        ),
    ]



from django.http import HttpResponse
from django.template import loader


def index(request):
	template = loader.get_template('unittests/index.html')
	return HttpResponse(template.render({}, request))


def switch_to(request):
	template = loader.get_template('unittests/switch_to.html')
	return HttpResponse(template.render({}, request))



# Generated by Django 2.0.2 on 2019-02-22 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Job',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('driver', models.CharField(max_length=256)),
                ('site', models.CharField(max_length=256)),
                ('status', models.CharField(max_length=256)),
                ('tag', models.CharField(max_length=256)),
                ('container', models.CharField(max_length=256)),
                ('log', models.TextField()),
            ],
        ),
    ]



import re
import json
import hashlib

from django.http import HttpResponse
from django.template import loader

from basicauth.decorators import basic_auth_required

from anna_client.client import Client


@basic_auth_required
def index(request):
	template = loader.get_template('index.html')
	return HttpResponse(template.render({}, request))


@basic_auth_required
def search(request):
	client = Client(endpoint='http://localhost:5000/graphql')
	query = {}
	for key, val in dict(request.GET).items():
		if key == 'hash':
			continue
		if isinstance(val, list):
			query[str(key).replace('[]', '') + '_in'] = val
		else:
			query[str(key).replace('[]', '')] = val
	response = client.get_jobs(where=query, fields=('id','status','driver','site','worker','container'))
	response_hash = hashlib.sha256(bytes(str(response).encode())).hexdigest()
	if 'hash' in query:
		if len(query['hash']) > 0 and query['hash'][0] == response_hash:
			return HttpResponse()
		del query['hash']
	jobs = []
	for job in response:
		jobs.append({
			'tag': job['container'], 'driver': job['driver'], 'site': job['site'], 'status': job['status'],
			'worker': job['worker']})
	return HttpResponse(json.dumps({'jobs': jobs, 'hash': response_hash}), content_type='application/json')



# Generated by Django 2.0.2 on 2019-02-22 16:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jobs', '0003_auto_20190222_1601'),
    ]

    operations = [
        migrations.AlterField(
            model_name='job',
            name='status',
            field=models.CharField(blank=True, max_length=256),
        ),
    ]



import setuptools

with open('README.md', 'r') as f:
	description = f.read()

setuptools.setup(
	name='anna-dashboard',
	version='0.0.2',
	author='Patrik Pihlstrom',
	author_email='patrik.pihlstrom@gmail.com',
	url='https://github.com/patrikpihlstrom/anna-dashboard',
	description='anna dashboard',
	long_decription=description,
	long_description_content_type='text/markdown',
	packages=['dashboard', 'dashboard.jobs', 'dashboard.unittests', 'dashboard.jobs.migrations', 'dashboard.unittests.migrations'],
	install_requires=['django', 'anna_client', 'django_basicauth', 'django_bootstrap_base_template', 'octicons']
)
